==> geeklog-1.6.0sr2-jp-1.0a.tar.gz: geeklog-1.6.0sr2-jp-1.0/plugins/staticpages/language/portuguese_brazil.php <==
<?php

###############################################################################
# portuguese_brazil.php
# Esta  a pgina em portugus do Brasil para o plug-in Geeklog Static Page!
#
# Traduo: Alcides Soares Filho (Maio de 2004)
# asoaresfil@uol.com.br
#
# Copyright (C) 2001 Tony Bibbs
# tony@tonybibbs.com
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################

global $LANG32;

###############################################################################
# Array Format:
# $LANGXX[YY]:  $LANG - variable name
#               XX    - file id number
#               YY    - phrase id number
###############################################################################

$LANG_STATIC = array(
    'newpage' => 'Nova Pgina',
    'adminhome' => 'Home Admin',
    'staticpages' => 'Pginas Estticas',
    'staticpageeditor' => 'Editor de Pginas Estticas',
    'writtenby' => 'Escrito por',
    'date' => 'ltima Atualizao',
    'title' => 'Ttulo',
    'content' => 'Contedo',
    'hits' => 'Hits',
    'staticpagelist' => 'Lista de Pginas Estticas',
    'url' => 'URL',
    'edit' => 'Edita',
    'lastupdated' => 'ltima Atualizao',
    'pageformat' => 'Formato da Pgina',
    'leftrightblocks' => 'Blocos  Esquerda & Direita',
    'blankpage' => 'Pgina em Branco',
    'noblocks' => 'Sem Blocos',
    'leftblocks' => 'Blocos  Esquerda',
    'addtomenu' => 'Adiciona ao Menu',
    'label' => 'Identificao',
    'nopages' => 'No h pginas estticas no sistema ainda',
    'save' => 'salva',
    'preview' => 'prev pgina',
    'delete' => 'apaga',
    'cancel' => 'cancela',
    'access_denied' => 'Acesso no autorizado',
    'access_denied_msg' => 'Voc est ilegalmente tentando acessar a pgina de administrao de Pginas Estticas.  Saiba que todas tentativas de acesso ilegal ficam registradas neste sistema',
    'all_html_allowed' => 'Todos cdigos HTML so permitidos',
    'results' => 'Resultado da Pgina Esttica',
    'author' => 'Autor',
    'no_title_or_content' => 'Voc deve ao menos preencher os campos de <b>Ttulo</b> e <b>Contedo</b>.',
    'no_such_page_anon' => 'Por favor faa o LOGIN...',
    'no_page_access_msg' => "Isto pode ter acontecido porque voc no efetuou o LOGIN, ou ainda porque no  membro do {$_CONF['site_name']}. Por favor <a href=\"{$_CONF['site_url']}/users.php?mode=new\"> torne-se um membro usurio do site</a> {$_CONF['site_name']} para ter acesso a todos recursos disponveis",
    'php_msg' => 'PHP: ',
    'php_warn' => 'Ateno: cdigo PHP dentro da sua pgina ser avaliado se voc solicitar esta opo. Use com cautela !!',
    'exit_msg' => 'Mensagem de Sada: ',
    'exit_info' => 'Habilita Mensagem informando que LOGIN  necessrio.  Deixe desmarcado para segurana normal e mensagem.',
    'deny_msg' => 'Acesso a esta pgina no permitido.  Ou a pgina foi movida/removida ou voc no tem permisso para acess-la.',
    'stats_headline' => 'Top 10 Pginas Estticas',
    'stats_page_title' => 'Ttulo da Pgina',
    'stats_hits' => 'Hits',
    'stats_no_hits' => 'Parece que ainda no h pginas estticas neste site ou que ainda nenhuma delas foi visitada.',
    'id' => 'ID',
    'duplicate_id' => 'A identidade - ID - que voc escolheu para esta pgina esttica j est em uso. Por favor selecione uma outra identidade - ID.',
    'instructions' => 'Para modificar ou apagar uma pgina esttica, clique no nmero da pgina abaixo. Para ver uma pgina esttica, clique no Ttulo da pgina que voc quer ver. Para criar uma npva pgina esttica, clica em Pgina Nova acima. Clique no [C] para criar uma cpia de uma pgina j existente.',
    'centerblock' => 'Centraliza Bloco: ',
    'centerblock_msg' => 'Quando marcado, faz com que a pgina esttica seja mostrada como um bloco central na pgina de ndice (index).',
    'topic' => 'Tpico: ',
    'position' => 'Posio: ',
    'all_topics' => 'Todos',
    'no_topic' => 'Somente Homepage',
    'position_top' => 'Topo da Pgina',
    'position_feat' => 'Depois de Publicao',
    'position_bottom' => 'P da Pgina',
    'position_entire' => 'Pgina Inteira',
    'head_centerblock' => 'Centraliza Bloco',
    'centerblock_no' => 'No',
    'centerblock_top' => 'Topo',
    'centerblock_feat' => 'P. Publicao',
    'centerblock_bottom' => 'Embaixo de tudo',
    'centerblock_entire' => 'Pgina Inteira',
    'inblock_msg' => 'Em um bloco: ',
    'inblock_info' => 'Espalha - Wrap - a Pgina Esttica no Bloco.',
    'title_edit' => 'Edita pgina',
    'title_copy' => 'Faz cpia desta pgina',
    'title_display' => 'Mostra pgina',
    'select_php_none' => 'no executa cdigo PHP',
    'select_php_return' => 'executa PHP (volta)',
    'select_php_free' => 'executa PHP',
    'php_not_activated' => "O uso de PHP em pginas estticas no est ativado. Por favor veja a <a href=\"{$_CONF['site_url']}/docs/english/staticpages.html#php\">documentao</a> para saber de mais detalhes.",
    'printable_format' => 'Printable Format',
    'copy' => 'Copy',
    'limit_results' => 'Limit Results',
    'search' => 'Search',
    'submit' => 'Submit'
);

$PLG_staticpages_MESSAGE15 = 'Your comment has been submitted for review and will be published when approved by a moderator.';
$PLG_staticpages_MESSAGE19 = 'Your page has been successfully saved.';
$PLG_staticpages_MESSAGE20 = 'Your page has been successfully deleted.';

// Messages for the plugin upgrade
$PLG_staticpages_MESSAGE3001 = 'Plugin upgrade not supported.';
$PLG_staticpages_MESSAGE3002 = $LANG32[9];

// Localization of the Admin Configuration UI
$LANG_configsections['staticpages'] = array(
    'label' => 'Static Pages',
    'title' => 'Static Pages Configuration'
);

$LANG_confignames['staticpages'] = array(
    'allow_php' => 'Allow PHP?',
    'sort_by' => 'Sort Centerblocks by',
    'sort_menu_by' => 'Sort Menu Entries by',
    'delete_pages' => 'Delete Pages with Owner?',
    'in_block' => 'Wrap Pages in Block?',
    'show_hits' => 'Show Hits?',
    'show_date' => 'Show Date?',
    'filter_html' => 'Filter HTML?',
    'censor' => 'Censor Content?',
    'default_permissions' => 'Page Default Permissions',
    'aftersave' => 'After Saving Page',
    'atom_max_items' => 'Max. Pages in Webservices Feed'
);

$LANG_configsubgroups['staticpages'] = array(
    'sg_main' => 'Main Settings'
);

$LANG_fs['staticpages'] = array(
    'fs_main' => 'Static Pages Main Settings',
    'fs_permissions' => 'Default Permissions'
);

// Note: entries 0, 1, 9, and 12 are the same as in $LANG_configselects['Core']
$LANG_configselects['staticpages'] = array(
    0 => array('True' => 1, 'False' => 0),
    1 => array('True' => true, 'False' => false),
    2 => array('Date' => 'date', 'Page ID' => 'id', 'Title' => 'title'),
    3 => array('Date' => 'date', 'Page ID' => 'id', 'Title' => 'title', 'Label' => 'label'),
    9 => array('Forward to page' => 'item', 'Display List' => 'list', 'Display Home' => 'home', 'Display Admin' => 'admin'),
    12 => array('No access' => 0, 'Read-Only' => 2, 'Read-Write' => 3)
);

?>

==> geeklog-1.6.1sr2-jp-1.0.tar.gz: geeklog-1.6.1sr2-jp-1.0/plugins/staticpages/language/portuguese_brazil.php <==
<?php

###############################################################################
# portuguese_brazil.php
# Esta  a pgina em portugus do Brasil para o plug-in Geeklog Static Page!
#
# Traduo: Alcides Soares Filho (Maio de 2004)
# asoaresfil@uol.com.br
#
# Copyright (C) 2001 Tony Bibbs
# tony@tonybibbs.com
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################

global $LANG32;

###############################################################################
# Array Format:
# $LANGXX[YY]:  $LANG - variable name
#               XX    - file id number
#               YY    - phrase id number
###############################################################################

$LANG_STATIC = array(
    'newpage' => 'Nova Pgina',
    'adminhome' => 'Home Admin',
    'staticpages' => 'Pginas Estticas',
    'staticpageeditor' => 'Editor de Pginas Estticas',
    'writtenby' => 'Escrito por',
    'date' => 'ltima Atualizao',
    'title' => 'Ttulo',
    'content' => 'Contedo',
    'hits' => 'Hits',
    'staticpagelist' => 'Lista de Pginas Estticas',
    'url' => 'URL',
    'edit' => 'Edita',
    'lastupdated' => 'ltima Atualizao',
    'pageformat' => 'Formato da Pgina',
    'leftrightblocks' => 'Blocos  Esquerda & Direita',
    'blankpage' => 'Pgina em Branco',
    'noblocks' => 'Sem Blocos',
    'leftblocks' => 'Blocos  Esquerda',
    'addtomenu' => 'Adiciona ao Menu',
    'label' => 'Identificao',
    'nopages' => 'No h pginas estticas no sistema ainda',
    'save' => 'salva',
    'preview' => 'prev pgina',
    'delete' => 'apaga',
    'cancel' => 'cancela',
    'access_denied' => 'Acesso no autorizado',
    'access_denied_msg' => 'Voc est ilegalmente tentando acessar a pgina de administrao de Pginas Estticas.  Saiba que todas tentativas de acesso ilegal ficam registradas neste sistema',
    'all_html_allowed' => 'Todos cdigos HTML so permitidos',
    'results' => 'Resultado da Pgina Esttica',
    'author' => 'Autor',
    'no_title_or_content' => 'Voc deve ao menos preencher os campos de <b>Ttulo</b> e <b>Contedo</b>.',
    'no_such_page_anon' => 'Por favor faa o LOGIN...',
    'no_page_access_msg' => "Isto pode ter acontecido porque voc no efetuou o LOGIN, ou ainda porque no  membro do {$_CONF['site_name']}. Por favor <a href=\"{$_CONF['site_url']}/users.php?mode=new\"> torne-se um membro usurio do site</a> {$_CONF['site_name']} para ter acesso a todos recursos disponveis",
    'php_msg' => 'PHP: ',
    'php_warn' => 'Ateno: cdigo PHP dentro da sua pgina ser avaliado se voc solicitar esta opo. Use com cautela !!',
    'exit_msg' => 'Mensagem de Sada: ',
    'exit_info' => 'Habilita Mensagem informando que LOGIN  necessrio.  Deixe desmarcado para segurana normal e mensagem.',
    'deny_msg' => 'Acesso a esta pgina no permitido.  Ou a pgina foi movida/removida ou voc no tem permisso para acess-la.',
    'stats_headline' => 'Top 10 Pginas Estticas',
    'stats_page_title' => 'Ttulo da Pgina',
    'stats_hits' => 'Hits',
    'stats_no_hits' => 'Parece que ainda no h pginas estticas neste site ou que ainda nenhuma delas foi visitada.',
    'id' => 'ID',
    'duplicate_id' => 'A identidade - ID - que voc escolheu para esta pgina esttica j est em uso. Por favor selecione uma outra identidade - ID.',
    'instructions' => 'Para modificar ou apagar uma pgina esttica, clique no nmero da pgina abaixo. Para ver uma pgina esttica, clique no Ttulo da pgina que voc quer ver. Para criar uma npva pgina esttica, clica em Pgina Nova acima. Clique no [C] para criar uma cpia de uma pgina j existente.',
    'centerblock' => 'Centraliza Bloco: ',
    'centerblock_msg' => 'Quando marcado, faz com que a pgina esttica seja mostrada como um bloco central na pgina de ndice (index).',
    'topic' => 'Tpico: ',
    'position' => 'Posio: ',
    'all_topics' => 'Todos',
    'no_topic' => 'Somente Homepage',
    'position_top' => 'Topo da Pgina',
    'position_feat' => 'Depois de Publicao',
    'position_bottom' => 'P da Pgina',
    'position_entire' => 'Pgina Inteira',
    'head_centerblock' => 'Centraliza Bloco',
    'centerblock_no' => 'No',
    'centerblock_top' => 'Topo',
    'centerblock_feat' => 'P. Publicao',
    'centerblock_bottom' => 'Embaixo de tudo',
    'centerblock_entire' => 'Pgina Inteira',
    'inblock_msg' => 'Em um bloco: ',
    'inblock_info' => 'Espalha - Wrap - a Pgina Esttica no Bloco.',
    'title_edit' => 'Edita pgina',
    'title_copy' => 'Faz cpia desta pgina',
    'title_display' => 'Mostra pgina',
    'select_php_none' => 'no executa cdigo PHP',
    'select_php_return' => 'executa PHP (volta)',
    'select_php_free' => 'executa PHP',
    'php_not_activated' => "O uso de PHP em pginas estticas no est ativado. Por favor veja a <a href=\"{$_CONF['site_url']}/docs/english/staticpages.html#php\">documentao</a> para saber de mais detalhes.",
    'printable_format' => 'Printable Format',
    'copy' => 'Copy',
    'limit_results' => 'Limit Results',
    'search' => 'Search',
    'submit' => 'Submit',
    'no_new_pages' => 'No new pages',
    'pages' => 'Pages'
);

$PLG_staticpages_MESSAGE15 = 'Your comment has been submitted for review and will be published when approved by a moderator.';
$PLG_staticpages_MESSAGE19 = 'Your page has been successfully saved.';
$PLG_staticpages_MESSAGE20 = 'Your page has been successfully deleted.';

// Messages for the plugin upgrade
$PLG_staticpages_MESSAGE3001 = 'Plugin upgrade not supported.';
$PLG_staticpages_MESSAGE3002 = $LANG32[9];

// Localization of the Admin Configuration UI
$LANG_configsections['staticpages'] = array(
    'label' => 'Static Pages',
    'title' => 'Static Pages Configuration'
);

$LANG_confignames['staticpages'] = array(
    'allow_php' => 'Allow PHP?',
    'sort_by' => 'Sort Centerblocks by',
    'sort_menu_by' => 'Sort Menu Entries by',
    'delete_pages' => 'Delete Pages with Owner?',
    'in_block' => 'Wrap Pages in Block?',
    'show_hits' => 'Show Hits?',
    'show_date' => 'Show Date?',
    'filter_html' => 'Filter HTML?',
    'censor' => 'Censor Content?',
    'default_permissions' => 'Page Default Permissions',
    'aftersave' => 'After Saving Page',
    'atom_max_items' => 'Max. Pages in Webservices Feed',
    'meta_tags' => 'Enable Meta Tags',
    'newstaticpagesinterval' => 'New Static Page Interval',
    'hidenewstaticpages' => 'Hide New Static Pages',
    'title_trim_length' => 'Title Trim Length',
    'includecenterblocks' => 'Include Center Block Static Pages',
    'includephp' => 'Include Static Pages with PHP',
    'includesearch' => 'Enable Static Pages in Search',
    'includesearchcenterblocks' => 'Include Center Block Static Pages',
    'includesearchphp' => 'Include Static Pages with PHP'
);

$LANG_configsubgroups['staticpages'] = array(
    'sg_main' => 'Main Settings'
);

$LANG_fs['staticpages'] = array(
    'fs_main' => 'Static Pages Main Settings',
    'fs_whatsnew' => 'What\'s New Block',
    'fs_search' => 'Search Results',
    'fs_permissions' => 'Default Permissions'
);

// Note: entries 0, 1, 9, and 12 are the same as in $LANG_configselects['Core']
$LANG_configselects['staticpages'] = array(
    0 => array('True' => 1, 'False' => 0),
    1 => array('True' => true, 'False' => false),
    2 => array('Date' => 'date', 'Page ID' => 'id', 'Title' => 'title'),
    3 => array('Date' => 'date', 'Page ID' => 'id', 'Title' => 'title', 'Label' => 'label'),
    9 => array('Forward to page' => 'item', 'Display List' => 'list', 'Display Home' => 'home', 'Display Admin' => 'admin'),
    12 => array('No access' => 0, 'Read-Only' => 2, 'Read-Write' => 3)
);

?>
